---
name: How To...?
about: Need help using xeofs? Get guidance here!
title: ''
labels: documentation
assignees: ''

---

**Describe the model you want to implement**
A clear and concise description of your goal. 

**Reproducible Minimal Working Example**
Provide a concise Python code snippet that demonstrates your approach. To display the code clearly, use [GitHub Flavored Markdown](http://github.github.com/github-flavored-markdown/) for formatting:

```python
import xeofs as xe

model = xe.single.EOF()
...
```

**Your problem**
A clear and concise description of what your problem is.

**Declaration**
- [ ] I have consulted the [documentation](https://xeofs.readthedocs.io/en/latest/) but could not find a solution.


**Desktop (please complete the following information):**
 - OS: [e.g. Ubuntu]
 - `xeofs` version [e.g. 1.2.0]

**Additional context**
Add any other context about the problem here.